% MATLAB_Control_Flow_Demo.m
% V1.0 - Ben Rowland 28 October 2020
% Enable Auto PID function and adjust the setpoint

clear all
global Control_Comms;

% Find the COM port on your PC where the Matrix EM control unit is plugged
% in and use it here instead of 'COM17'

Control_Comms = serial('COM17','Baudrate',115200,'Databits',8);
fopen(Control_Comms);

%Setup Flow with input and feedback scaler
ScaleFactor = 520700;
Calibration = 0.830000;
InputScaler = ScaleFactor * Calibration;
OutputScaler = 0.357100;
SetFeedbackMethod(1, InputScaler, OutputScaler);

%Set Kp gain
SetAutoPIDParam (0, 2.64);

%Set Ki gain
SetAutoPIDParam (1, 40.6);

%Set Kd gain
SetAutoPIDParam (2, 0.0429);

%Set Integral Clamping On
SetAutoPIDParam (3, 1);

%Set Derivative Filter On
SetAutoPIDParam (4, 1);

%Set Derivative Coefficient
SetAutoPIDParam (5, 10);

%Set the PID Error Flip
SetAutoPIDFlip (0);

%Enable Auto PID on Pump at 100Hz
SetAutoPID (0, 5);

%Set required flow rate
SetAutoPIDSetpoint (200);

%Record response for 2 seconds
index = 1;
for loop = 0:200
  feedback(index) = GetFeedback();
  output(index) = GetOutput();
  P(index) = GetPIDComponent(0);
  I(index) = GetPIDComponent(1);
  D(index) = GetPIDComponent(2);
  idx(index) = index;
  index = index + 1;
  pause(0.01);
end

%Disable Auto PID
SetAutoPID (0, 0);

%Output the feedback and output responses
plot(index, feedback, index, output);

%Output the P, I and D output components
plot(index, P, index, I, index, D);
